/**
 * Script of the section block.
 *
 * @since 0.27.0
 * @package WordPress
 * @subpackage ANRGHG Publishing Helper
 *
 * @courtesy A White Pixel and Novo-Media.
 * @link https://novo-media.ch/en/programming-coding/gutenberg-plugin-development-wp-data-wordpress-rest-api/
 * @link https://awhitepixel.com/blog/wordpress-gutenberg-create-custom-block-part-2-register-block/
 * @link https://awhitepixel.com/blog/wordpress-gutenberg-create-custom-block-tutorial/
 */


import { __ } from '@wordpress/i18n';
import { registerBlockType } from '@wordpress/blocks';
import { InspectorControls } from '@wordpress/blockEditor';
import { TextControl, RadioControl, CheckboxControl, PanelBody, PanelRow } from '@wordpress/components';


const pipeInfo = __( 'Used as a delimiter, the vertical bar “|” is escaped.', 'anrghg' );
var   escaPipeAlertDo;
if ( anrghgSection.showEscaPipeAlert ) {
	escaPipeAlertDo = true;
} else {
	escaPipeAlertDo = false;
}

function escaPipe( str ) {
	if ( str.indexOf( '|' ) >= 0 ) {
		str = str.replace( /\|/g, '&#x7C;' );
		if ( escaPipeAlertDo ) {
			alert( pipeInfo );
			escaPipeAlertDo = false;
		}
	}
	return str;
}


registerBlockType( 'anrghg/notes-and-references', {

	title: __( 'Notes and references', 'anrghg' ),
	description: __( 'Determine the position of a set of complement lists. Else the result is as configured in the ANRGHG Publishing Helper.', 'anrghg' ),
	icon: 'editor-justify',
	category: 'design',
	keywords: [
		__( 'sections', 'anrghg' ),
		__( 'endnotes', 'anrghg' ),
		__( 'complements', 'anrghg' ),
		__( 'reusables', 'anrghg' ),
		__( 'citations', 'anrghg' ),
		__( 'bibliograph', 'anrghg' ),
		__( 'footer', 'anrghg' ),
	],
	supports: {
		multiple: true,
	},

	attributes: {

		noteListLabel: {
			type: 'string',
			default: '',
		},

		noteDir: {
			type: 'string',
			default: anrghgSection.defaultDirNotes,
			value: 'selected',
		},

		refListLabel: {
			type: 'string',
			default: '',
		},

		refDir: {
			type: 'string',
			default: anrghgSection.defaultDirRefs,
			value: 'selected',
		},

		inFooter: {
			type: 'string',
			default: '0',
			value: 'selected',
		},

	},

	edit: ( props ) => {

		const { attributes, setAttributes } = props;

		const purpose = (
			<p
				style={ {
					fontStyle: 'italic',
					textAlign: 'center',
				} }
			>{ __( 'Here ends a section for complements to be listed down to this point.', 'anrghg' ) }</p>
		);

		const icFooter = (
			<PanelBody
				title={ __( 'Footer', 'anrghg' ) }
				initialOpen={ true }
			>
				<fieldset>
					<legend>
						{ <strong>{ __( 'Footer deferral of lists', 'anrghg' ) }</strong> }
					</legend>
					<RadioControl
						selected={ attributes.inFooter }
						options={ [
							{
								label: __( 'Leave as configured', 'anrghg' ),
								value: '0',
							},
							{
								label: __( 'Defer to footer', 'anrghg' ),
								value: '1',
							},
							{
								label: __( 'Keep in article', 'anrghg' ),
								value: '-1',
							},
						] }
						onChange={ ( val ) => setAttributes( { inFooter: val } ) }
					/>
				</fieldset>
			</PanelBody>
		);

		const labelNotes = (
			<TextControl
				label={ __( 'Note list label tailored to the instance:', 'anrghg' ) }
				style={ {
					fontSize: '18px',
				} }
				placeholder={ anrghgSection.configListLabelNotes }
				help={ anrghgSection.helpListLabelNotes }
				autoComplete={ 'off' }
				value={ escaPipe( attributes.noteListLabel ) }
				onChange={ ( typed ) => setAttributes( { noteListLabel: escaPipe( typed ) } ) }
			/>
		);

		const labelRefs = (
			<TextControl
				label={ __( 'Reference list label tailored to the instance:', 'anrghg' ) }
				style={ {
					fontSize: '18px',
				} }
				placeholder={ anrghgSection.configListLabelRefs }
				help={ anrghgSection.helpListLabelRefs }
				autoComplete={ 'off' }
				value={ escaPipe( attributes.refListLabel ) }
				onChange={ ( typed ) => setAttributes( { refListLabel: escaPipe( typed ) } ) }
			/>
		);

		const blockLegendDir = (
			<legend
				style={ {
					position: 'absolute',
					width: '0',
					height: '0',
					overflow: 'hidden',
				} }
			>
				{ __( 'Writing direction', 'anrghg' ) }
			</legend>
		);

		const icLegendDirNotes = (
			<legend>
				{ <strong>{ __( 'Notes', 'anrghg' ) }</strong> }
			</legend>
		);

		const icLegendDirRefs = (
			<legend>
				{ <strong>{ __( 'References', 'anrghg' ) }</strong> }
			</legend>
		);

		const dirRadioNotes = (
			<RadioControl
				selected={ attributes.noteDir }
				options={ [
					{
						label: __( 'left-to-right', 'anrghg' ),
						value: '1',
					},
					{
						label: __( 'right-to-left', 'anrghg' ),
						value: '-1',
					},
					{
						label: __( 'unspecified', 'anrghg' ),
						value: '0',
					},
				] }
				onChange={ ( val ) => setAttributes( { noteDir: val } ) }
			/>
		);

		const dirRadioRefs = (
			<RadioControl
				selected={ attributes.refDir }
				options={ [
					{
						label: __( 'left-to-right', 'anrghg' ),
						value: '1',
					},
					{
						label: __( 'right-to-left', 'anrghg' ),
						value: '-1',
					},
					{
						label: __( 'unspecified', 'anrghg' ),
						value: '0',
					},
				] }
				onChange={ ( val ) => setAttributes( { refDir: val } ) }
			/>
		);

		const blockDirNotes = (
			<fieldset>
				{ blockLegendDir }
				{ dirRadioNotes }
			</fieldset>
		);

		const blockDirRefs = (
			<fieldset>
				{ blockLegendDir }
				{ dirRadioRefs }
			</fieldset>
		);

		const icDirNotes = (
			<fieldset>
				{ icLegendDirNotes }
				{ dirRadioNotes }
			</fieldset>
		);

		const icDirRefs = (
			<fieldset>
				{ icLegendDirRefs }
				{ dirRadioRefs }
			</fieldset>
		);

		function BlockLabelDir( props ) {
			return (
				<div
					style={ {
						display: 'flex',
					} }
				>
					<div
						style={ {
							flexGrow: '1',
						} }
					>
						{ 'notes' === props.type ? labelNotes : labelRefs }
					</div>
					<div
						title={ __( 'Writing direction', 'anrghg' ) }
						style={ {
							flexShrink: '0',
							padding: '12px 10px 0',
						} }
					>
						{ 'notes' === props.type ? blockDirNotes : blockDirRefs }
					</div>
				</div>
			);
		}

		const icLabels = (
			<PanelBody
				title={ __( 'Labels', 'anrghg' ) }
				initialOpen={ false }
			>
				{ labelNotes }
				{ labelRefs }
			</PanelBody>
		);

		const icDir = (
			<PanelBody
				title={ __( 'Writing direction', 'anrghg' ) }
				initialOpen={ false }
			>
				{ icDirNotes }
				{ icDirRefs }
			</PanelBody>
		);

		let full = false;
		let half = false;
		let zero = false;

		switch ( anrghgSection.sectionBlockSettings ) {
			case '2': full = true; break;
			case '1': half = true; break;
			default:  zero = true;
		}

		return (
			<>
				<InspectorControls>
					{ icFooter }
					{ zero && icLabels }
					{ ! full && icDir }
				</InspectorControls>
				{ zero ?
					<div
						style={ {
							border: '1px solid #000',
							paddingTop: '20px',
							fontSize: 'smaller',
						} }
					>
						{ purpose }
					</div>
				:
					<div
						style={ {
							border: '1px solid #000',
							paddingTop: '20px',
							paddingBottom: '7px',
							paddingInlineStart: '30px',
							paddingInlineEnd: '15px',
							fontSize: 'smaller',
							textAlign: 'start',
						} }
					>
						{ purpose }
						{ full && <BlockLabelDir type='notes' /> }
						{ full && <BlockLabelDir type='refs' /> }
						{ half && labelNotes }
						{ half && labelRefs }
					</div>
				}
			</>
		);

	},

	save: ( props ) => {

		const { attributes } = props;

		let positioner = '[anrghg_section';

		if ( attributes.noteListLabel ) {
			positioner += ' _1=|' + escaPipe( attributes.noteListLabel ) + '|';
		}

		if ( attributes.refListLabel ) {
			positioner += ' _2=|' + escaPipe( attributes.refListLabel ) + '|';
		}

		if ( '0' !== attributes.noteDir ) {
			positioner += ' _3=|' + attributes.noteDir + '|';
		}

		if ( '0' !== attributes.refDir ) {
			positioner += ' _4=|' + attributes.refDir + '|';
		}

		if ( '0' !== attributes.inFooter ) {
			positioner += ' _5=|' + attributes.inFooter + '|';
		}

		positioner += ']';

		return ( positioner );

	},

} );
