<?php
/**
 * Templates for configuration filters, ANRGHG Publishing Helper.
 *
 * CAUTION: Please do not edit this file in this plugin folder,
 * since it is not connected to the plugin, and like all files
 * in this folder it will be overwritten during plugin updates.
 *
 * NOTE: These filters override values set for the same options
 * in the plugin’s Settings page in the Admin area and saved to
 * the database.
 *
 * NOTE FOR MULTILINGUAL websites with string translation pane:
 * String translations are effective only for strings stored in
 * the database, because translation managers filter strings as
 * they are retrieved at a `get_option()` function call.
 *
 * HOW TO: You may add any of these templates in functions.php,
 * after deriving a child theme from the theme currently in use
 * in your WordPress instance. Just copy-paste and edit.
 *
 * Deriving a child theme from your current theme may be done
 * by the Generate Child Theme plugin from Catch Plugins.
 * Never start theme names with a digit, always with a letter
 * in range a-z or A-Z, or with an underscore.
 *
 * @link https://wordpress.org/plugins/generate-child-theme/
 * @link https://catchplugins.com/plugins/generate-child-theme/
 *
 * Some of these options are already in the plugin’s settings,
 * and those that are not yet will be added there.
 *
 * We apologize for the plugin’s unfinished configuration page
 * while the ANRGHG Publishing Helper stays under construction
 * after its release was fast-tracked in response to a precise
 * user request for an end notes plugin to be AMP-compatible.
 *
 * TECHNICAL NOTE: All values of the settings, like the default
 * values as filled in below for template purpose, are strings,
 * and there are no numbers (integers or floating decimals) nor
 * Booleans (true or false), for consistency with the way these
 * are stored in the database. However, in PHP the *string* '0'
 * evaluates as false while all other strings evaluate as true.
 *
 * @since 0.24.0
 * @package WordPress
 * @subpackage ANRGHG Publishing Helper
 */
defined( 'ABSPATH' ) or exit( nl2br( "\r\n\r\n&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;This PHP file cannot be displayed in the browser." ) );



/**
 * Security enhancement: Stay logged in and don’t leave the login dialog available non-stop.
 *
 * This security enhancement allows to deactivate the WordPress login dialog
 * and to activate it using the hosting platform file manager during narrow,
 * spaced-out windows. Unlike hosting platform login information, WordPress
 * website login information is transparent to SQL injection attacks.
 *
 * The risk associated with keeping login dialogs live indefinitely far
 * outweighs the risk induced by keeping limited sets of users logged in
 * during longer periods of time rather than a couple weeks (14 days).
 *
 * @link https://resources.infosecinstitute.com/topic/hacking-a-wordpress-site/
 * @link https://secure.wphackedhelp.com/blog/hack-wordpress-website/
 * @link https://www.cloudways.com/blog/wordpress-sql-injection-protection/
 *
 * This solution requires adding the following lines in your `wp-config.php`
 * and editing the Boolean value periodically.
 * @see template in `templates-for-additions-to-wp-config.php`.
 *
 *     // Turn login off by replacing true with false:
 *     define( 'ANRGHG_WP_LOGIN_ACTIVE', true );
 *
 * This solution is based on code from Jonathan Daggerhart (@daggerhart on GitHub).
 * @link https://gist.github.com/daggerhart/d19821ff8ce836a5fc68
 *
 * Alternatively, a low-profile behavior keeps the login screen displayed
 * but login is ineffective, by blocking authentication cookie generation
 * and sending to the user agent. This contrasts with the replacement of
 * the dialog with a red-banded message (high profile), and with its mere
 * disappearance as originally intended (intermediate profile).
 *
 * Complementarily to deactivating the login dialog, an additional feature
 * reduces the number of login windows, the number of times collaborators
 * need to be synced for the login action, and the number of edits to the
 * `wp-config.php` file. If this feature is activated and configured ahead
 * of the next login window, participants stay logged in during the freely
 * configured number of days.
 *
 * This feature is available if and only if ANRGHG_WP_LOGIN_ACTIVE is defined,
 * and enabling this feature also requires an additional explicit user action.
 *
 * This feature is based on code from Jenson Felsberg.
 * @link http://wpcodesnippet.com/keep-users-logged-in-longer-wordpress/
 */

/**
 * This option determines the way the login page displays while deactivated.
 *
 * Values:
 * '1':  High profile: The login dialog is replaced with a red-banded message;
 * '0':  Intermediate: The login dialog disappears but without elaborating;
 * '-1': Low profile:  Only the auth cookie generation/sending is blocked:
 */
add_filter( 'anrghg_login_deactivation_profile', function() { return '0'; } );

/**
 * The switch to turn the next setting on or off.
 * Normally, authentication cookies expire after 14 days if “☐ Remember me”
 * is checked, after 2 days if the checkbox is unchecked.
 *
 * Values: '0' or '1' (or any other string):
 * Login duration is configurable only if ANRGHG_WP_LOGIN_ACTIVE is defined:
 */
add_filter( 'anrghg_auth_duration_edit', function() { return '0'; } );

/**
 * This is the number of days that the next authentication cookies are valid:
 */
add_filter( 'anrghg_auth_expiration_days', function() { return '31'; } );



/**
 * Append a message to posts or pages.
 *
 * Originally designed as an example and targeting posts.
 *
 * A text box is optionally displayed at the end of the posts.
 * It may also display with another content at the end of pages.
 *
 * This feature is based on code from Justin Busa.
 * @link https://www.wpbeaverbuilder.com/creating-wordpress-plugin-easier-think/
 */

/**
 * Activation and scope are united in this switch.
 *
 * Values:
 * '1': Append a message to posts;
 * '3': Append one message to posts and another one to pages;
 * '2': Append a message to pages only;
 * '0': Deactivate this feature:
 */
add_filter( 'anrghg_thank_you_active', function() { return '0'; } );

/**
 * The priority level matters as it determines the order relative to
 * other features appended by this or other plugins.
 *
 * Values:
 * '-1': Highest priority;
 * '0':  Input the priority level as an integer;
 * '1':  Lowest priority:
 */
add_filter( 'anrghg_thank_you_priority_select', function() { return '0'; } );

/**
 * Values: any integer numeric string, at least between '-2147483648' and '2147483647':
 */
add_filter( 'anrghg_thank_you_priority_input', function() { return '10'; } );

/**
 * Your message at the end of posts:
 */
add_filter( 'anrghg_thank_you_content', function() { return 'Thank you for reading!'; } );

/**
 * Your message at the end of pages:
 */
add_filter( 'anrghg_thank_you_content_page', function() { return 'Thank you for reading this page!'; } );



/**
 * Display last modified (and/or published) date.
 *
 * The published and/or last modified dates are appended or prepended
 * to the post or page. Consistently with current practice, both dates
 * are link text of the permalink, and a tooltip shows the time.
 *
 * This feature is based on code from Shaun Quarton.
 * @link https://pagely.com/blog/display-post-last-updated-wordpress/
 */

/**
 * This is the main switch. Effectiveness depends on the next 8 switches.
 *
 * All these settings are '0' or '1':
 * '1': Modified and/or published date may be added;
 * '0': Modified and/or published date cannot be added:
 */
add_filter( 'anrghg_dates_active', function() { return '0'; } );

/**
 * '1': Add the last-modified date at the beginning of posts:
 */
add_filter( 'anrghg_dates_post_top_modif', function() { return '1'; } );

/**
 * '1': Add the published date at the beginning of posts:
 */
add_filter( 'anrghg_dates_post_top_publi', function() { return '0'; } );

/**
 * '1': Add the last-modified date at the end of posts:
 */
add_filter( 'anrghg_dates_post_end_modif', function() { return '0'; } );

/**
 * '1': Add the published date at the end of posts:
 */
add_filter( 'anrghg_dates_post_end_publi', function() { return '0'; } );

/**
 * '1': Add the last-modified date at the beginning of pages:
 */
add_filter( 'anrghg_dates_page_top_modif', function() { return '0'; } );

/**
 * '1': Add the published date at the beginning of pages:
 */
add_filter( 'anrghg_dates_page_top_publi', function() { return '0'; } );

/**
 * '1': Add the last-modified date at the end of pages:
 */
add_filter( 'anrghg_dates_page_end_modif', function() { return '1'; } );

/**
 * '1': Add the published date at the end of pages:
 */
add_filter( 'anrghg_dates_page_end_publi', function() { return '1'; } );

/**
 * The order when both dates are added in the same place.
 *
 * Values:
 * '1': Published date first, last-modified date second (chronological order);
 * '0': Last-modified date first, published date second (anti-chronological order);
 */
add_filter( 'anrghg_dates_chronological', function() { return '0'; } );

/**
 * Whether to use unified labels or labels specifically tailored to the instance.
 *
 * Values:
 * '1': Use unified, general labels;
 * '0': Use labels specifically tailored to the instance:
 */
add_filter( 'anrghg_dates_label_uni', function() { return '1'; } );

/**
 * The unified, general label for all instances of last-modified date:
 */
add_filter( 'anrghg_dates_label_modified', function() { return 'Last modified:'; } );

/**
 * The unified, general label for all instances of published date:
 */
add_filter( 'anrghg_dates_label_published', function() { return 'Published:'; } );

/**
 * The specific label of the last-modified date at the beginning of posts:
 */
add_filter( 'anrghg_dates_label_post_top_modif', function() { return 'Post last modified:'; } );

/**
 * The specific label of the published date at the beginning of posts:
 */
add_filter( 'anrghg_dates_label_post_top_publi', function() { return 'Post published:'; } );

/**
 * The specific label of the last-modified date at the end of posts:
 */
add_filter( 'anrghg_dates_label_post_end_modif', function() { return 'This post was last modified on'; } );

/**
 * The specific label of the published date at the end of posts:
 */
add_filter( 'anrghg_dates_label_post_end_publi', function() { return 'This post was published on'; } );

/**
 * The specific label of the last-modified date at the beginning of pages:
 */
add_filter( 'anrghg_dates_label_page_top_modif', function() { return 'Page last modified:'; } );

/**
 * The specific label of the published date at the beginning of pages:
 */
add_filter( 'anrghg_dates_label_page_top_publi', function() { return 'Page published:'; } );

/**
 * The specific label of the last-modified date at the end of pages:
 */
add_filter( 'anrghg_dates_label_page_end_modif', function() { return 'This page was last modified on'; } );

/**
 * The specific label of the published date at the end of pages:
 */
add_filter( 'anrghg_dates_label_page_end_publi', function() { return 'This page was published on'; } );

/**
 * The priority level matters as it determines the order relative to
 * other features appended by this or other plugins.
 *
 * Values:
 * '-1': Highest priority;
 * '0':  Input the priority level as an integer;
 * '1':  Lowest priority:
 */
add_filter( 'anrghg_dates_priority_select', function() { return '0'; } );

/**
 * Values: any integer numeric string, at least between '-2147483648' and '2147483647':
 */
add_filter( 'anrghg_dates_priority_input', function() { return '1500'; } );



/**
 * Add date meta tags in the page head.
 *
 * Last modified date and published date are used by search engines
 * and bibliography software. One or both of these meta tags may be
 * missing, and may be added by Search Engine Optimization plugins.
 */

/**
 * Activation.
 *
 * Values:
 * '1': Add both published and last modified date meta tags;
 * '0': Deactivate this feature:
 */
add_filter( 'anrghg_date_meta_tags_active', function() { return '0'; } );

/**
 * Format.
 *
 * Values:
 * '1': Open Graph format;
 * '':  Common format:
 */
add_filter( 'anrghg_date_meta_tags_format', function() { return ''; } );



/**
 * Links to paragraphs and list items.
 *
 * This feature adds fragment identifiers to paragraphs, prepends clickable
 * extra elements, and this way helps share direct links in a fine-grained,
 * precisely targeted manner, as opposed to the way a table of contents can
 * be set up, targeting headings only.
 *
 * Purple Numbers were the original paragraph IDs by Douglas Engelbart, and
 * the name was given by his daughter looking at the purple-colored numbers
 * appended to the paragraphs.
 *
 * The ANRGHG Publishing Helper generates fragment identifiers based on the
 * content, in an attempt to work around the way continuously updated pages
 * are compromising the stability of identifiers based on numbering.
 *
 * Edits affecting the first 200 characters of paragraphs or list items are
 * compromising this stability, so this still suboptimal solution is only a
 * workaround, but an intuitive one, with URLs reflecting the wording to be
 * expected.
 */

/**
 * The switch to turn this feature on and off.
 *
 * Values:
 * '1':  Add fragment IDs to paragraphs;
 * '0':  Deactivate this feature:
 */
add_filter( 'anrghg_paragraph_links_active', function() { return '0'; } );

/**
 * This is the prepended character used as link text for the paragraph link.
 *
 * The character is prepended visually only, not in the text stream.
 * Suggestions: ¶, §, 🔗 (U+1F517)
 */
add_filter( 'anrghg_paragraph_link_character', function() { return '¶'; } );



/**
 * Table of contents and heading links.
 *
 * When the ANRGHG Publishing Helper adds fragment identifiers to headings,
 * it uses the heading as link text, making it clickable.
 *
 * Independently, a table of contents may be present, either collapsed or
 * expanded when the page is loaded. If it is collapsible, it may also be
 * expanded at load, instead of being collapsed, making collapsing merely
 * a convenience, like in MediaWiki.
 *
 * Expanding and collapsing the table of contents on clicking its label or
 * the twistie next to it works even when JavaScript is turned off in the
 * browser.
 *
 * Headings are numbered by CSS counters, and the heading numbers link back
 * to their counterpart in the table of contents.
 *
 * The heading numbers are currently appended and semi-transparent to prevent
 * them from being too obtrusive, to account for the majority preference for
 * having heading numbers in the table of contents, but not in the article.
 */

/**
 * This is the switch of the heading links, that may stand alone.
 *
 * Values:
 * '1': Heading links;
 * '0': Deactivate this feature:
 */
add_filter( 'anrghg_heading_links_active', function() { return '0'; } );

/**
 * The switch of the table of contents has 3 positions because beyond
 * being active, the feature may also apply always if enough headings
 * are present, or only on request if a positioner is in the article.
 *
 * Values:
 *  '1': Always show the table of contents if applicable;
 * '-1': Insert a table of contents only on request;
 *  '0': Deactivate this feature:
 */
add_filter( 'anrghg_table_of_contents_active', function() { return '0'; } );

/**
 * The table’s label may be blank, since a twistie is appended if the table is collapsible:
 */
add_filter( 'anrghg_table_of_contents_label', function() { return 'Table of contents'; } );

/**
 * The minimum number of headings:
 */
add_filter( 'anrghg_table_of_contents_min_number', function() { return '2'; } );

/**
 * Depth; '6' lists all headings (recommended):
 */
add_filter( 'anrghg_table_of_contents_depth', function() { return '6'; } );

/**
 * Default position in the absence of a positioner.
 *
 * Values:
 * '1':  At the top of the article just below the title;
 * '0':  Before the first heading;
 * '-1': Appended at the bottom:
 */
add_filter( 'anrghg_table_of_contents_position', function() { return '0'; } );

/**
 * Table of contents configurable positioner.
 *
 * To help with inserting a positioner, a block is available in the Block Editor.
 */
add_filter( 'anrghg_table_of_contents_positioner', function() { return '[TOC]'; } );

/**
 * Whether the table of contents is collapsible, and whether it is collapsed by default.
 *
 * Values:
 * '1':  Collapsed when the page loads, expands on click;
 * '-1': Displays expanded on load, collapsible on click:
 * '0':  Always displays in full length, cannot collapse;
 */
add_filter( 'anrghg_table_of_contents_collapsed', function() { return '1'; } );



/**
 * Complements as end notes and references.
 *
 * This is not active by default either so as to not interfere with
 * other, more specialized plugins handling end notes or references
 * but not both like the MediaWiki CMS does.
 *
 * NOTE: Two options about controlling the output of end note lists
 * or reference lists in the footer are required before filters are
 * available and therefore should be configured in the options page
 * so as to have the values stored in the database and available at
 * the required early moment in the page generation process.
 *
 * TECHNICAL NOTE: The settings page has an option for a predefined
 * set of safe delimiters and anoter one for easy-to-input strings,
 * but these are handled too early for being subject to filters.
 */

/**
 * Activation.
 *
 * Values:
 * '1': Process both end notes and references as defined inline;
 * '0': Deactivate this feature:
 */
add_filter( 'anrghg_complements_active', function() { return '1'; } );

/**
 * Define the string delimiting the start of an end note text.
 *
 * Suggestions:
 * - Easy input:   '{{{';
 * - Unambiguous:  '[note]';
 * - Free example: '[σημ]':
 */
add_filter( 'anrghg_note_start', function() { return '[note]'; } );

/**
 * Define the string delimiting the end of an end note text.
 *
 * Suggestions:
 * - Easy input:   '}}}';
 * - Unambiguous:  '[/note]';
 * - Free example: '[/σημ]':
 */
add_filter( 'anrghg_note_end', function() { return '[/note]'; } );

/**
 * Define the string delimiting the start of a reference text.
 *
 * Suggestions:
 * - Easy input:   '[[[';
 * - Unambiguous:  '[ref]';
 * - Free example: '[упом]':
 */
add_filter( 'anrghg_reference_start', function() { return '[ref]'; } );

/**
 * Define the string delimiting the end of a reference text.
 *
 * Suggestions:
 * - Easy input:   ']]]';
 * - Unambiguous:  '[/ref]';
 * - Free example: '[/упом]':
 */
add_filter( 'anrghg_reference_end', function() { return '[/ref]'; } );

/**
 * Label for lists of multiple notes.
 */
add_filter( 'anrghg_list_label_notes_plural', function() { return 'Notes'; } );

/**
 * Label for lists of multiple references.
 */
add_filter( 'anrghg_list_label_references_plural', function() { return 'References'; } );

/**
 * List layout options for notes or references.
 *
 * Values:
 * '1': Display the lists in 1 column;
 * '2': Display the lists in 2 columns, except on mobiles;
 * '3': Display the lists in 3 columns, except on mobiles:
 */
add_filter( 'anrghg_note_list_layout',      function() { return '1'; } );
add_filter( 'anrghg_reference_list_layout', function() { return '1'; } );



/**
 * Option to deactivate WPTexturize.
 *
 * By default, WordPress converts a number of ASCII strings to strings
 * containing non-ASCII characters except inside a number of elements.
 * Both the list of these elements and the lists of conversions may be
 * customized.
 *
 * The `wptexturize()` function applies filters so as to short-circuit
 * it entirely by `add_filter( 'run_wptexturize', '__return_false' )`,
 * which can be used directly instead of the filter added below.
 *
 * To deactivate WPTexturize, set the return value below to '0'. Then,
 * using a Unicode-supporting keyboard layout gives full control as of
 * what a quotation mark or a dash is represented by in any particular
 * instance.
 */
add_filter( 'anrghg_wptexturize_active', function() { return '1'; } );



/**
 * Use the URL slug as a CSS selector.
 *
 * After activating this feature (set to '1'), you may use the slug of
 * any page or post as a class of the body element in CSS style rules.
 *
 * NOTE: Slugs starting with a digit will be prepended with
 * an underscore to make valid CSS class names out of them.
 *
 * CAUTION: Two posts or pages may happen to have the same slug. These
 * will be applied the same style rules if defined using the slug. The
 * problem cannot be addressed by prepending generic strings, while no
 * prepended strings means easier, more straightforward selectors. For
 * pages or posts with identical slugs but differing requirements, the
 * number should be used. It is a body class by default, and is unique
 * across posts and pages. However, to make a valid CSS class name out
 * of it, WordPress prepends a string of letters:
 * - Posts: Prepend `postid-`  to the number;
 * - Pages: Prepend `page-id-` to the number.
 */
add_filter( 'anrghg_slug_body_class_active', function() { return '0'; } );



/**
 * Other filters are being added as soon as implemented and documented.
 *
 * Our apologies for releasing the ANRGHG Publishing Helper while it is
 * still under construction, out of an urgency when a plugin generating
 * end notes was requested to be AMP compatible on the support forum of
 * the official AMP plugin.
 */
